@@ -31,6 +31,7 @@ impl Boolean {
 impl NumberInstance for Boolean {
     type Abs = Self;
     type Exp = Float;
+    type Log = Float;
     type Class = BooleanType;
 
     fn class(&self) -> BooleanType {
@@ -49,6 +50,13 @@ impl NumberInstance for Boolean {
         Float::cast_from(self).exp()
     }
 
+    fn log<N: NumberInstance>(self, base: N) -> Self::Log
+    where
+        Float: From<N>,
+    {
+        Float::cast_from(self).log(base)
+    }
+
     fn pow(self, exp: Number) -> Self {
         if exp.cast_into() {
             self
@@ -255,6 +263,7 @@ pub enum Complex {
 impl NumberInstance for Complex {
     type Abs = Float;
     type Exp = Self;
+    type Log = Self;
     type Class = ComplexType;
 
     fn class(&self) -> ComplexType {
@@ -293,6 +302,16 @@ impl NumberInstance for Complex {
         }
     }
 
+    fn log<N: NumberInstance>(self, base: N) -> Self::Log
+    where
+        Float: From<N>,
+    {
+        match self {
+            Self::C32(c) => c.log(Float::from(base).cast_into()).into(),
+            Self::C64(c) => c.log(Float::from(base).cast_into()).into(),
+        }
+    }
+
     fn pow(self, exp: Number) -> Self {
         match self {
             Self::C64(this) => match exp {
@@ -695,6 +714,7 @@ pub enum Float {
 impl NumberInstance for Float {
     type Abs = Float;
     type Exp = Self;
+    type Log = Self;
     type Class = FloatType;
 
     fn class(&self) -> FloatType {
@@ -733,6 +753,16 @@ impl NumberInstance for Float {
         }
     }
 
+    fn log<N: NumberInstance>(self, base: N) -> Self::Log
+    where
+        Float: From<N>,
+    {
+        match self {
+            Self::F32(f) => f.log(Float::from(base).cast_into()).into(),
+            Self::F64(f) => f.log(Float::from(base).cast_into()).into(),
+        }
+    }
+
     fn pow(self, exp: Number) -> Self {
         match self {
             Self::F64(this) => match exp {
@@ -1111,6 +1141,7 @@ pub enum Int {
 impl NumberInstance for Int {
     type Abs = Self;
     type Exp = Float;
+    type Log = Float;
     type Class = IntType;
 
     fn class(&self) -> IntType {
@@ -1166,6 +1197,14 @@ impl NumberInstance for Int {
         Float::from(self).exp()
     }
 
+    fn log<N: NumberInstance>(self, base: N) -> Self::Log
+    where
+        Float: From<N>,
+    {
+        let this: Float = self.into();
+        this.log(base)
+    }
+
     fn pow(self, exp: Number) -> Self {
         if exp < exp.class().zero() {
             return self.class().zero();
@@ -1578,6 +1617,7 @@ pub enum UInt {
 impl NumberInstance for UInt {
     type Abs = Self;
     type Exp = Float;
+    type Log = Float;
     type Class = UIntType;
 
     fn class(&self) -> UIntType {
@@ -1628,6 +1668,14 @@ impl NumberInstance for UInt {
         Float::from(self).exp()
     }
 
+    fn log<N: NumberInstance>(self, base: N) -> Self::Log
+    where
+        Float: From<N>,
+    {
+        let this: Float = self.into();
+        this.log(base)
+    }
+
     fn pow(self, exp: Number) -> Self {
         if exp < Number::from(0) {
             return self.class().zero();
